Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1699)

Unified Diff: chrome/browser/dom_ui/mediaplayer_ui.h

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/dom_ui/mediaplayer_ui.h
diff --git a/chrome/browser/dom_ui/mediaplayer_ui.h b/chrome/browser/dom_ui/mediaplayer_ui.h
index 5c5b4bcb381df2e4f2ee00bc4d322e8ed95b7a89..8a34d7c7f442b55f9e8ad42169603b37b3103d30 100644
--- a/chrome/browser/dom_ui/mediaplayer_ui.h
+++ b/chrome/browser/dom_ui/mediaplayer_ui.h
@@ -24,7 +24,7 @@ class MediaplayerHandler;
class Browser;
class MediaPlayer : public NotificationObserver,
- public URLRequest::Interceptor {
+ public net::URLRequest::Interceptor {
public:
~MediaPlayer();
@@ -74,13 +74,13 @@ class MediaPlayer : public NotificationObserver,
// Always returns NULL because we don't want to attempt a redirect
// before seeing the detected mime type of the request.
// Implementation of URLRequest::Interceptor.
virtual net::URLRequestJob* MaybeIntercept(net::URLRequest* request);
// Determines if the requested document can be viewed by the
// MediaPlayer. If it can, returns a URLRequestJob that
// redirects the browser to the view URL.
// Implementation of URLRequest::Interceptor.
virtual net::URLRequestJob* MaybeInterceptResponse(net::URLRequest* request);
// Used to detect when the mediaplayer is closed.
@@ -74,13 +74,13 @@ class MediaPlayer : public NotificationObserver,
// Always returns NULL because we don't want to attempt a redirect
// before seeing the detected mime type of the request.
- // Implementation of URLRequest::Interceptor.
+ // Implementation of net::URLRequest::Interceptor.
virtual net::URLRequestJob* MaybeIntercept(net::URLRequest* request);
// Determines if the requested document can be viewed by the
@@ -74,13 +74,13 @@ class MediaPlayer : public NotificationObserver,
// MediaPlayer. If it can, returns a URLRequestJob that
// redirects the browser to the view URL.
- // Implementation of URLRequest::Interceptor.
+ // Implementation of net::URLRequest::Interceptor.
virtual net::URLRequestJob* MaybeInterceptResponse(net::URLRequest* request);
// Used to detect when the mediaplayer is closed.

Powered by Google App Engine
This is Rietveld 408576698